************
Introduction
************

*Everviz* is a plugin for *Everest* that enables plotting of the results of an optimization. The *Everest* tool is designed for optimizing well drilling order and time under geological uncertainty. The results of the optimization include control and function values, as they evolve during the optimization. In addition, the simulators that are used in the optimization process produce various time series of summary values at each iteration, each of which may involve multiple simulation runs.

*Everviz* is designed to plot the control, function and summary values produced during the optimization run. *Everviz* is based on `Webviz <https://github.com/equinor/webviz-config>`_, a *Dash*-based tool for creating plotting applications using `yaml` configuration files.